==> songfindercli-0.3.8-py2-none-any.whl: songfinder/data/documentation/README.md <==

# Documentation :

- Pour accéder à la documentation, cliquer sur `Aide`, puis sur `Documentation` dans le menu déroulé.
- Elle est également disponible sur internet par ce lien :
[http://interne.eglise-pe-franconville.fr/files/techniqueFranconville.html](http://interne.eglise-pe-franconville.fr/files/techniqueFranconville.html)


# Récupérer la base de données des chants :

La base de données est stocké dans un dépôt sur internet.
Pour l'avoir sur l'ordinateur, il faut cloner le dépôt.

- Aller dans `Editer->Paramètres Généraux` et cocher `Synchroniser la base de données`.
- Confirmer et remplir les trois champs :
	- Chemin : *https://epef@bitbucket.org/epef/data*
	- Utilisateur : *Daniel [Mettre votre prénom]*
	- Mot de passe : *\*\*\* [Mettre le mot de passe]*
- Cliquer sur `Cloner`.
La base de données est maintenant sur l'ordinateur.


# Ajouter des accords (prendre pour exemple *Hosanna à l'agneau immolé*) :

- Sélectionner un chant
- Ajouter une ligne débutant par `\ac` et continuant par les accords devant être affichés.
- Les accords sont associés aux lignes juste au dessus la ligne contenant les accords.
- Les accords peuvent être renseigné dans la notation francophone ou anglophone.
- Ne remplir les accords que pour un couplet et un refrain, pas besoin de dupliquer chaque série d'accords.
- Renseigner la tonalité et le nombre de demis ton de transposition (en haut).


# Envoyer les modifications et récupérer celles des autres contributeurs :

- Dans le menu `Réception/Envoi`, cliquer sur `Envoyer les chants` ou `Recevoir les chants`
- Avant des faire des modifications, il faut vérifier que quelqu'un d'autre ne les ai pas déjà faite en cliquant sur `Recevoir les chants`.
- Après avoir fait les modifications, il faut envoyer les chants en cliquant sur `Envoyer les chants`.


# Créer un PDF :

- Faire un double clique sur un chant dans la liste des résultats de recherche (en haut) pour le mettre dans la liste des sélections (en bas).
- Répéter cette précédente étape pour tous les chants devant être dans le PDF
- Cliquer sur le bouton `Générer un PDF` (à droite)
- Cocher les options souhaitées
- Enregistrer

==> songfindercli-0.4.2-py2-none-any.whl: songfinder/data/documentation/README.md <==

# Documentation :

- Pour accéder à la documentation, cliquer sur `Aide`, puis sur `Documentation` dans le menu déroulé.
- Elle est également disponible sur internet par ce lien :
[http://interne.eglise-pe-franconville.fr/files/techniqueFranconville.html](http://interne.eglise-pe-franconville.fr/files/techniqueFranconville.html)


# Récupérer la base de données des chants :

La base de données est stocké dans un dépôt sur internet.
Pour l'avoir sur l'ordinateur, il faut cloner le dépôt.

- Aller dans `Editer->Paramètres Généraux` et cocher `Synchroniser la base de données`.
- Confirmer et remplir les trois champs :
	- Chemin : *https://epef@bitbucket.org/epef/data*
	- Utilisateur : *Daniel [Mettre votre prénom]*
	- Mot de passe : *\*\*\* [Mettre le mot de passe]*
- Cliquer sur `Cloner`.
La base de données est maintenant sur l'ordinateur.


# Ajouter des accords (prendre pour exemple *Hosanna à l'agneau immolé*) :

- Sélectionner un chant
- Ajouter une ligne débutant par `\ac` et continuant par les accords devant être affichés.
- Les accords sont associés aux lignes juste au dessus la ligne contenant les accords.
- Les accords peuvent être renseigné dans la notation francophone ou anglophone.
- Ne remplir les accords que pour un couplet et un refrain, pas besoin de dupliquer chaque série d'accords.
- Renseigner la tonalité et le nombre de demis ton de transposition (en haut).


# Envoyer les modifications et récupérer celles des autres contributeurs :

- Dans le menu `Réception/Envoi`, cliquer sur `Envoyer les chants` ou `Recevoir les chants`
- Avant des faire des modifications, il faut vérifier que quelqu'un d'autre ne les ai pas déjà faite en cliquant sur `Recevoir les chants`.
- Après avoir fait les modifications, il faut envoyer les chants en cliquant sur `Envoyer les chants`.


# Créer un PDF :

- Faire un double clique sur un chant dans la liste des résultats de recherche (en haut) pour le mettre dans la liste des sélections (en bas).
- Répéter cette précédente étape pour tous les chants devant être dans le PDF
- Dans le menu `Latex` cliquer sur l'entrée' `Générer un fichier PDF` (à droite)
- Cocher les options souhaitées
- Enregistrer
